Release History
===============

**0.1.5 2016-07-07**

*   Changed getting the user's id from pwd.getpwuid() to os.getuid() for
    Windows compatibility

**0.1.4 2016-06-16**

*   some work to get it into pypi


**0.1.0 2016-06-13**

*   initial release
